custom_slidable/action_pane_motions library

Classes

BehindMotion
An ActionPane motion which reveals actions as if they were behind the Slidable.
DrawerMotion
An ActionPane motion which reveals actions as if they were drawers.
ScrollMotion
An ActionPane motion which reveals actions as if they were scrolling from the outside.
StretchMotion
An ActionPane motion which reveals actions by stretching their extent while sliding the CustomSlidableAction.