custom_slidable/auto_close_behavior library

Classes

CustomSlidableAutoCloseBehaviorInteractor
INTERNAL USE
CustomSlidableAutoCloseNotificationSender
INTERNAL USE
SlidableAutoCloseBarrierBehaviorListener
INTERNAL USE
SlidableAutoCloseBarrierInteractor
INTERNAL USE
SlidableAutoCloseBarrierNotification
A notification used to indicate if a barrier should be pub on Slidable
SlidableAutoCloseBarrierNotificationSender
INTERNAL USE
SlidableAutoCloseBehavior
A widget that forces the Slidable widgets below it to close when another Slidable widget with the same groupTag opens.
SlidableAutoCloseBehaviorListener
INTERNAL USE
SlidableAutoCloseInteractor
INTERNAL USE
SlidableAutoCloseNotification
A notification used to close other Slidable widgets with the same groupTag.