SlidableAutoCloseBarrierNotification class

A notification used to indicate if a barrier should be pub on Slidable

Annotations

Constructors

SlidableAutoCloseBarrierNotification({required Object? groupTag, required CustomSlidableController controller, bool enabled = false})
Creates a notification to activate/deactivate the barrier on Slidable widgets.
const

Properties

controller CustomSlidableController
The CustomSlidableController associated.
final
enabled bool
Whether the barrier is enabled.
final
groupTag Object?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited