custom_slidable/controller library

Classes

ClosingGesture
Represents a gesture used explicitly to close a Slidable.
CustomSlidableController
Represents a way to control a slidable from outside.
DismissGesture
Represents an intention to dismiss a Slidable.
EndGesture
Represents the end of a gesture on Slidable.
OpeningGesture
Represents a gesture used explicitly to open a Slidable.
RatioConfigurator
Represents how the ratio should changes.
ResizeRequest
A request made to resize a Slidable after a dismiss.
StillGesture
Represents an end gesture without velocity.

Enums

ActionPaneType
The different kinds of action panes.
GestureDirection
The direction of a gesture in the context of Slidable.

Constants

kDefaultExtentRatio → const double