initialExtentRatio property
The extent ratio of this widget in its parent when mainAxisExtent's value is 0..
Implementation
final double initialExtentRatio;
The extent ratio of this widget in its parent when mainAxisExtent's value is 0..
final double initialExtentRatio;