onPressed property
Called when the action is tapped or otherwise activated.
If this callback is null, then the action will be disabled.
Implementation
final CustomSlidableActionCallback? onPressed;
Called when the action is tapped or otherwise activated.
If this callback is null, then the action will be disabled.
final CustomSlidableActionCallback? onPressed;