SlidableAutoCloseNotification class
A notification used to close other Slidable widgets with the same
groupTag.
- Annotations
Constructors
- SlidableAutoCloseNotification({required Object? groupTag, required CustomSlidableController controller, bool closeSelf = false})
-
Creates a notification that can be used to close other
Slidablewidgets with the samegroupTag.const
Properties
- closeSelf → bool
-
Whether the
Slidablewhere this notification was sent should also close.final - controller → CustomSlidableController
-
The CustomSlidableController associated.
final
- groupTag → Object?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited